/* 
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Benjamin Grauer
   co-programmer: ...
   
   Some code was taken from Simon's first implementation of the SoundEngine.
*/

#define DEBUG_SPECIAL_MODULE DEBUG_MODULE_SOUND

#include "sound_engine.h"

using namespace std;

/**
   \brief standard constructor
*/
SoundEngine::SoundEngine () 
{
   this->setClassName ("SoundEngine");
   this->isInit = false;
   this->enableSound();
}

//! brief the singleton reference to this class
SoundEngine* SoundEngine::singletonRef = NULL;

/**
   \returns a Pointer to this Class
*/
SoundEngine* SoundEngine::getInstance(void)
{
  if (!SoundEngine::singletonRef)
    SoundEngine::singletonRef = new SoundEngine();
  return SoundEngine::singletonRef;
}

/**
   \brief standard deconstructor

*/
SoundEngine::~SoundEngine () 
{
  SoundEngine::singletonRef = NULL;
  
  this->disableSound();
}


/**
   \brief enables the SDL_mixer library
*/
void SoundEngine::enableSound(void)
{
  if (!this->isInit)
    if (SDL_Init(SDL_INIT_AUDIO))
      {
	PRINTF(1)("SDL-sound could not be initialized\n");
	return;
      }
  this->isInit = true;
}

/**
   \brief disabled SDL_mixer
*/
void SoundEngine::disableSound(void)
{
  if (this->isInit)
    {
      SDL_QuitSubSystem(SDL_INIT_AUDIO);
    }
  else
    PRINTF(4)("SDL_mixer was not initialized.\n");
}

/**
   \brief checks if the compiled version and the local version of SDL_mixer match.
   \returns true if match, false otherwise
*/
bool SoundEngine::checkVersion(void)
{
  SDL_version compile_version;
  SDL_version link_version;
  MIX_VERSION(&compile_version);
  link_version = *Mix_Linked_Version();

  if (compile_version.major == link_version.major &&
      compile_version.minor == link_version.minor &&
      compile_version.patch == link_version.patch)
    {
      return true;
    }
  else
    {
      PRINTF(2)("compiled with SDL_mixer version: %d.%d.%d\n", 
		compile_version.major,
		compile_version.minor,
		compile_version.patch);
      
      PRINTF(2)("running with SDL_mixer version: %d.%d.%d\n", 
		link_version.major,
		link_version.minor,
		link_version.patch);
      return false;
    }
}
