/*! 
    \file sound_engine.h
    \brief Definition of the SoundEngine

    !!AVOID!!:
    SDL_OpenAudio
     Use Mix_OpenAudio instead. 
    SDL_CloseAudio
     Use Mix_CloseAudio instead. 
    SDL_PauseAudio
     Use Mix_Pause(-1) and Mix_PauseMusic instead, to pause.
     Use Mix_Resume(-1) and Mix_ResumeMusic instead, to unpause. 
    SDL_LockAudio
     This is just not needed since SDL_mixer handles this for you.
     Using it may cause problems as well. 
    SDL_UnlockAudio
     This is just not needed since SDL_mixer handles this for you.
     Using it may cause problems as well. 
*/

#ifndef _SOUND_ENGINE_H
#define _SOUND_ENGINE_H

#include "base_object.h"
#include <SDL_mixer.h>

// FORWARD DEFINITION

//! The Main Sound Engine
class SoundEngine : public BaseObject {

 public:
  static SoundEngine* getInstance(void);
  virtual ~SoundEngine(void);

 private:
  SoundEngine(void);
  static SoundEngine* singletonRef;

  
  
  void enableSound(void);
  void disableSound(void);
  static bool checkVersion(void);

  bool isInit;
};


#endif /* _SOUND_ENGINE_H */
